import os
import logger

def check_upload_file(upload_file):
    logger.info("Checking upload file...")
    if os.path.isdir(upload_file):
        logger.info("Folder exists: " + upload_file)
        for root, dirs, files in os.walk(upload_file):
            for file in files:
                if file == "Packages.gz" or file == "Packages":
                    logger.info("Packages file found: " + file + " ,assuming this is a valid folder for upload")
                    return True
                else:
                    logger.error("Packages file not found: " + file)
                    return False
    else:
        logger.error("File not valid or not exist: " + upload_file)
        return False



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
import logging
from .arg_parse import arg_parse

home_dir = os.path.expanduser("~")
config_file = home_dir + "/.config/robin/software_deployment.yaml"


log_filename = 'upload.log'
log_level = logging.INFO
log_format = '%(asctime)s %(levelname)s %(message)s'

logging.basicConfig(filename=log_filename, level=log_level, format=log_format)
logger = logging.getLogger()

def main():
    arg_parse(config_file)

if __name__ == "__main__":
    main()